==> rook_users-0.4.1.tar.gz: lib/src/authorization/authorization_manager.dart <==
import 'package:jwt_decode/jwt_decode.dart';
import 'package:logging/logging.dart';
import 'package:rook_users/src/authorization/authorization_api_service.dart';
import 'package:rook_users/src/authorization/authorization_preferences.dart';
import 'package:rook_users/src/authorization/get_expiration_date_from_json_web_token.dart';
import 'package:rook_users/src/domain/exception/rook_users_not_initialized_exception.dart';

class AuthorizationManager {
  static AuthorizationManager? _instance;
  static String? clientUUID;

  final Logger _logger = Logger('RookUsersManager');
  final AuthorizationApiService _apiService = AuthorizationApiService();
  final AuthorizationPreferences _preferences = AuthorizationPreferences();

  DateTime _expirationDate = DateTime.timestamp();

  AuthorizationManager._();

  factory AuthorizationManager() {
    return _instance ??= AuthorizationManager._();
  }

  Future<DateTime> authorize(String clientUUID) async {
    AuthorizationManager.clientUUID = clientUUID;

    _logger.info('Fetching remote authorization...');

    try {
      final jsonWebToken = await getJsonWebToken(clientUUID);

      _expirationDate = getExpirationDateFromJsonWebToken(jsonWebToken);

      await _preferences.setExpirationDate(_expirationDate);

      _logger.info('Fetched remote authorization, expiration date: $_expirationDate');
      return _expirationDate;
    } catch (exception) {
      _logger.warning('Could not fetch remote authorization, switching to local storage...');

      _expirationDate = await _preferences.getExpirationDate();

      if (_isAuthorized()) {
        _logger.info('Found local authorization, expiration date: $_expirationDate');
        return _expirationDate;
      } else {
        _logger.info('Could not find local authorization: $exception');
        rethrow;
      }
    }
  }

  Future<Map<String, dynamic>> getJsonWebToken(String clientUUID) async {
    final response = await _apiService.getAuthorization(clientUUID);
    final jsonWebToken = Jwt.parseJwt(response.jwt);

    return jsonWebToken;
  }

  bool _isAuthorized() {
    final now = DateTime.timestamp();

    return now.isBefore(_expirationDate);
  }

  void checkAuthorization() {
    if (!_isAuthorized()) {
      throw RookUsersNotInitializedException();
    }
  }
}

==> rook_users-0.5.1.tar.gz: lib/src/authorization/authorization_manager.dart <==
import 'package:jwt_decode/jwt_decode.dart';
import 'package:logging/logging.dart';
import 'package:rook_users/src/authorization/authorization_api_service.dart';
import 'package:rook_users/src/authorization/authorization_preferences.dart';
import 'package:rook_users/src/authorization/get_expiration_date_from_json_web_token.dart';
import 'package:rook_users/src/domain/exception/rook_users_not_initialized_exception.dart';

class AuthorizationManager {
  static AuthorizationManager? _instance;
  static String? clientUUID;

  final Logger _logger = Logger('RookUsersManager');
  final AuthorizationApiService _apiService = AuthorizationApiService();
  final AuthorizationPreferences _preferences = AuthorizationPreferences();

  DateTime _expirationDate = DateTime.timestamp();

  AuthorizationManager._();

  factory AuthorizationManager() {
    return _instance ??= AuthorizationManager._();
  }

  Future<DateTime> authorize(String clientUUID) async {
    AuthorizationManager.clientUUID = clientUUID;

    _logger.info('Fetching remote authorization...');

    try {
      final jsonWebToken = await getJsonWebToken(clientUUID);

      _expirationDate = getExpirationDateFromJsonWebToken(jsonWebToken);

      await _preferences.setExpirationDate(_expirationDate);

      _logger.info(
          'Fetched remote authorization, expiration date: $_expirationDate');
      return _expirationDate;
    } catch (exception) {
      _logger.warning(
          'Could not fetch remote authorization, switching to local storage...');

      _expirationDate = await _preferences.getExpirationDate();

      if (_isAuthorized()) {
        _logger.info(
            'Found local authorization, expiration date: $_expirationDate');
        return _expirationDate;
      } else {
        _logger.info('Could not find local authorization: $exception');
        rethrow;
      }
    }
  }

  Future<Map<String, dynamic>> getJsonWebToken(String clientUUID) async {
    final response = await _apiService.getAuthorization(clientUUID);
    final jsonWebToken = Jwt.parseJwt(response.jwt);

    return jsonWebToken;
  }

  bool _isAuthorized() {
    final now = DateTime.timestamp();

    return now.isBefore(_expirationDate);
  }

  void checkAuthorization() {
    if (!_isAuthorized()) {
      throw RookUsersNotInitializedException();
    }
  }
}
